@@ -13,17 +13,21 @@ do_view_action() {
 
     case "${filetype}" in
     iso9660)
-         isoinfo -d -i "${MC_EXT_FILENAME}" && isoinfo -l -R -J -i "${MC_EXT_FILENAME}"
+         if which isoinfo > /dev/null 2>&1; then
+             isoinfo -d -i "${MC_EXT_FILENAME}" && isoinfo -l -R -J -i "${MC_EXT_FILENAME}"
+         else
+             7za l "${MC_EXT_FILENAME}"
+         fi
         ;;
     cat)
-        /bin/cat "${MC_EXT_FILENAME}" 2>/dev/null
+        cat "${MC_EXT_FILENAME}" 2>/dev/null
         ;;
     ar)
         file "${MC_EXT_FILENAME}" && nm -C "${MC_EXT_FILENAME}"
         ;;
     lib)
         gplib -t "${MC_EXT_FILENAME}" | \
-            /usr/bin/perl -e 'while (<>) { @a=split /[\s\t]+/, $_; printf ("%-30s | %10d | %s.%s.%02d | %s\n", $a[0], ($a[1]*1),$a[7], lc($a[4]), $a[5], $a[6]);}'
+            /2022Q2/bin/perl -e 'while (<>) { @a=split /[\s\t]+/, $_; printf ("%-30s | %10d | %s.%s.%02d | %s\n", $a[0], ($a[1]*1),$a[7], lc($a[4]), $a[5], $a[6]);}'
         ;;
     so)
         file "${MC_EXT_FILENAME}" && nm -C -D "${MC_EXT_FILENAME}"
@@ -48,7 +52,8 @@ do_view_action() {
         ctorrent -x "${MC_EXT_FILENAME}" 2>/dev/null
         ;;
     javaclass)
-        jad -p "${MC_EXT_FILENAME}" 2>/dev/null
+        jad -p "${MC_EXT_FILENAME}" 2>/dev/null || \
+            (file -b "${MC_EXT_FILENAME}"; javap -private "${MC_EXT_FILENAME}" 2>/dev/null)
         ;;
     *)
         ;;
@@ -59,9 +64,6 @@ do_open_action() {
     filetype=$1
 
     case "${filetype}" in
-    imakefile)
-        xmkmf -a
-        ;;
     dbf)
         dbview "${MC_EXT_FILENAME}"
         ;;
@@ -69,7 +71,7 @@ do_open_action() {
         sqlite3 "${MC_EXT_FILENAME}"
         ;;
     glade)
-        if glade-3 --version >/dev/null 2>&1; then
+        if which glade-3 >/dev/null 2>&1; then
             (glade-3 "${MC_EXT_FILENAME}" >/dev/null 2>&1 &)
         else
             (glade-2 "${MC_EXT_FILENAME}" >/dev/null 2>&1 &)
@@ -91,7 +93,7 @@ view)
     do_view_action "${filetype}"
     ;;
 open)
-    "${MC_XDG_OPEN}" "${MC_EXT_FILENAME}" 2>/dev/null || \
+    ("${MC_XDG_OPEN}" "${MC_EXT_FILENAME}" >/dev/null 2>&1) || \
         do_open_action "${filetype}"
     ;;
 *)
