@@ -15,7 +15,8 @@ do_view_action() {
     html)
         links -dump "${MC_EXT_FILENAME}" 2>/dev/null || \
             w3m -dump "${MC_EXT_FILENAME}" 2>/dev/null || \
-            lynx -dump -force_html "${MC_EXT_FILENAME}"
+            lynx -dump -force_html "${MC_EXT_FILENAME}" 2>/dev/null ||
+            cat "${MC_EXT_FILENAME}"
         ;;
     *)
         ;;
@@ -27,8 +28,8 @@ do_open_action() {
 
     case "${filetype}" in
     html)
-        (if [ -n "konqueror" -a  -n "$DISPLAY" ]; then
-            (konqueror file://"${MC_EXT_CURRENTDIR}"/"${MC_EXT_BASENAME}" &) 1>&2
+        (if [ -n "firefox" -a  -n "$DISPLAY" ]; then
+            (firefox file://"${MC_EXT_CURRENTDIR}"/"${MC_EXT_BASENAME}" &) 1>&2
         else
             elinks "${MC_EXT_FILENAME}" || \
                 links "${MC_EXT_FILENAME}" || \
